interface AllQuestionsCount {
    difficulty: string;
    count: number;
}
interface Contributions {
    points: number;
    questionCount: number;
    testcaseCount: number;
}
interface Profile {
    realName: string;
    websites: string[];
    countryName: string | null;
    skillTags: string[];
    company: string | null;
    school: string | null;
    starRating: number;
    aboutMe: string;
    userAvatar: string;
    reputation: number;
    ranking: number;
}
interface AcSubmissionNum {
    difficulty: string;
    count: number;
    submissions: number;
}
interface TotalSubmissionNum {
    difficulty: string;
    count: number;
    submissions: number;
}
interface SubmitStats {
    acSubmissionNum: AcSubmissionNum[];
    totalSubmissionNum: TotalSubmissionNum[];
}
interface Badge {
    id: string;
    displayName: string;
    icon: string;
    creationDate?: string;
}
interface MatchedUser {
    username: string;
    socialAccounts: unknown;
    githubUrl: null;
    contributions: Contributions;
    profile: Profile;
    submissionCalendar: string;
    submitStats: SubmitStats;
    badges: Badge[];
    upcomingBadges: Badge[];
    activeBadge: Badge | null;
}
interface RecentSubmission {
    title: string;
    titleSlug: string;
    timestamp: string;
    statusDisplay: string;
    lang: string;
}
interface UserProfile {
    allQuestionsCount: AllQuestionsCount[];
    matchedUser: MatchedUser | null;
    recentSubmissionList: RecentSubmission[] | null;
}
interface TopicTag {
    name: string;
    slug: string;
    translatedName: string | null;
}
interface CodeSnippet {
    lang: string;
    langSlug: string;
    code: string;
}
interface OfficialSolution {
    id: string;
    canSeeDetail: boolean;
    paidOnly: boolean;
    hasVideoSolution: boolean;
    paidOnlyVideo: boolean;
}
interface ChallengeQuestion {
    id: string;
    date: string;
    incompleteChallengeCount: number;
    streakCount: number;
    type: string;
}
declare type ProblemDifficulty = "Easy" | "Medium" | "Hard";
interface Problem {
    questionId: string;
    questionFrontendId: string;
    boundTopicId: unknown;
    title: string;
    titleSlug: string;
    content: string;
    translatedTitle: string | null;
    translatedContent: string | null;
    isPaidOnly: boolean;
    difficulty: ProblemDifficulty;
    likes: number;
    dislikes: number;
    isLiked: boolean | null;
    similarQuestions: string;
    exampleTestcases: string;
    contributors: unknown[];
    topicTags: TopicTag[];
    companyTagStats: unknown;
    codeSnippets: CodeSnippet[];
    stats: string;
    hints: string[];
    solution: OfficialSolution;
    status: unknown;
    sampleTestCase: string;
    metaData: string;
    judgerAvailable: boolean;
    judgeType: string;
    mysqlSchemas: unknown[];
    enableRunCode: boolean;
    enableTestMode: boolean;
    enableDebugger: boolean;
    envInfo: string;
    libraryUrl: string | null;
    adminUrl: string | null;
    challengeQuestion: ChallengeQuestion;
}
declare type SubmissionStatus = "Accepted" | "Wrong Answer" | "Time Limit Exceeded" | "Memory Limit Exceeded" | "Output Limit Exceeded" | "Compile Error" | "Runtime Error";
interface Submission {
    id: number;
    lang: string;
    time: string;
    timestamp: number;
    status_display: SubmissionStatus;
    runtime: string;
    url: string;
    is_pending: string;
    title: string;
    memory: string;
    code: string;
    compare_result: string;
    title_slug: string;
}

interface CacheItem {
    key: string;
    value: unknown;
    expires: number;
}
interface CacheTable {
    [key: string]: CacheItem;
}
interface ICredential {
    session?: string;
    csrf?: string;
}
interface LeetCodeGraphQLQuery {
    operationName: string;
    variables: {
        [key: string]: unknown;
    };
    query: string;
}
interface LeetCodeGraphQLResponse {
    data: UserProfile | RecentSubmission[] | any;
}

declare class Credential implements ICredential {
    session?: string;
    csrf?: string;
    constructor(data?: ICredential);
    init(session?: string): Promise<this>;
}

declare class Cache {
    private _table;
    get(key: string): unknown;
    set(key: string, value: unknown, expires?: number): void;
    remove(key: string): void;
    clear(): void;
    load(json: string): void;
}
declare const cache: Cache;
declare const caches: {
    [key: string]: Cache;
};

declare class LeetCode {
    credential: Credential;
    cache: Cache;
    private initialized;
    constructor(credential?: Credential | null, cache?: Cache | null);
    get_user(username: string): Promise<UserProfile>;
    get_recent_submissions(username: string, limit?: number): Promise<RecentSubmission[]>;
    get_submissions(limit?: number, offset?: number, cooldown?: number): Promise<Submission[]>;
    get_problem(slug: string): Promise<Problem>;
    graphql(query: LeetCodeGraphQLQuery): Promise<LeetCodeGraphQLResponse>;
}

declare const BASE_URL = "https://leetcode.com";
declare const USER_AGENT = "Mozilla/5.0 LeetCode API";

export { AcSubmissionNum, AllQuestionsCount, BASE_URL, Badge, Cache, CacheItem, CacheTable, ChallengeQuestion, CodeSnippet, Contributions, Credential, ICredential, LeetCode, LeetCodeGraphQLQuery, LeetCodeGraphQLResponse, MatchedUser, OfficialSolution, Problem, ProblemDifficulty, Profile, RecentSubmission, Submission, SubmissionStatus, SubmitStats, TopicTag, TotalSubmissionNum, USER_AGENT, UserProfile, cache, caches, LeetCode as default };
